View source: R/barrel_prepare.R
| barrel_prepare | R Documentation |
Attaches sample metadata (e.g., grouping variable) to a vegan ordination object and assigns class 'barrel_ord'.
barrel_prepare(ord, metadata)
ord |
A vegan ordination object (e.g., from |
metadata |
A data frame of sample metadata. Must have same number of rows as ordination site scores. |
The ordination object with metadata attached and class "barrel_ord".
library(vegan)
data(dune)
data(dune.env)
ord <- rda(dune, scale = TRUE)
ord_prepared <- barrel_prepare(ord, dune.env)
class(ord_prepared)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.