get_ord_axis_labels: Internal function to get axis labels for vegan ordination...

View source: R/7.get_ord_axis_labels.R

get_ord_axis_labelsR Documentation

Internal function to get axis labels for vegan ordination objects

Description

This function infers the ordination method used and returns proper axis labels including percentage of explained variance when applicable.

Usage

get_ord_axis_labels(ord)

Arguments

ord

A vegan ordination object.

Value

A list with one element label, a character vector for axis labels. #' @examples library(vegan) data(dune) data(dune.env) ord_pca <- rda(dune) get_ord_axis_labels(ord_pca)


barrel documentation built on Nov. 5, 2025, 7:40 p.m.