View source: R/3.ord_ellipse_groups.R
| ord_ellipse_groups | R Documentation |
Calculates ellipse coordinates for all groups in ordination scores.
ord_ellipse_groups(
scores,
group_var,
axis1,
axis2,
kind = "se",
conf = 0.95,
method = "classic"
)
scores |
Data frame of ordination scores. |
group_var |
Name of grouping column. |
axis1 |
Name of first axis column. |
axis2 |
Name of second axis column. |
kind |
Type of ellipse: "se" or "sd". |
conf |
Confidence level. |
method |
Covariance method: "classic" or "robust". |
Compute ellipse coordinates for all groups in ordination scores
Calculates ellipse coordinates for all groups in ordination scores, supports classic and robust covariance estimation.
Data frame of ellipse coordinates with group labels.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.