View source: R/5.ord_extract_centroids.R
| ord_extract_centroids | R Documentation |
Computes centroids per group using classic mean or robust methods.
ord_extract_centroids(
scores,
group_var,
axis1,
axis2,
method = c("classic", "robust")
)
scores |
Data frame of ordination scores. |
group_var |
Name of grouping column. |
axis1 |
Name of first axis column. |
axis2 |
Name of second axis column. |
method |
Centroid method: "classic" or "robust". |
Extract centroids of groups from ordination scores with classic or robust method
Computes the centroid coordinates for each group using either the classical mean or robust minimum covariance determinant.
Data frame with group centroids.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.