View source: R/7.get_ord_axis_labels.R
| get_ord_axis_labels | R Documentation |
This function infers the ordination method used and returns proper axis labels including percentage of explained variance when applicable.
get_ord_axis_labels(ord)
ord |
A vegan ordination object. |
A list with one element label, a character vector for axis labels.
#' @examples
library(vegan)
data(dune)
data(dune.env)
ord_pca <- rda(dune)
get_ord_axis_labels(ord_pca)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.